| Queue-class | R Documentation |
A Queue reference class
dataInitial data to populate the queue.
peek(pos = c(1), as.list = FALSE)Returns (but does not remove) specified positions in queue (or NULL if any one of them is not available). The as.list argument will cause a list to be returned even if only one element requested.
poll()Removes and returns head of queue (or NULL if queue is empty).
pop(N = 1)Removes and returns head of queue (or raises error if queue is empty). N is number of items to pop.
push(item)Inserts element at back of the queue.
size()Returns the number of items in the queue.
queue <- Queue$new()
queue$push("one")
queue$push(2)
queue$push("three")
queue$size()
queue$pop()
queue$poll()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.